action_to_message

Function action_to_message 

fn action_to_message(action: KeyAction) -> Option<Message>
Map a semantic key action to a Message.

Returns Some for all currently implemented actions. The Option return type is retained for the .and_then(action_to_message) call pattern and for forward compatibility when new KeyAction variants are added before their Message counterparts.