fn build_patchset_row<'a>(
app: &'a App,
ps: &'a Patchset,
palette: &'a ColorPalette,
) -> Row<'a>Expand description
Build a single table row for a patchset in the list view.
fn build_patchset_row<'a>(
app: &'a App,
ps: &'a Patchset,
palette: &'a ColorPalette,
) -> Row<'a>Build a single table row for a patchset in the list view.