fn panel_border_color(
current_focus: FocusPanel,
panel: FocusPanel,
palette: &ColorPalette,
) -> ColorExpand description
Return the border color for a panel based on whether it has focus.
fn panel_border_color(
current_focus: FocusPanel,
panel: FocusPanel,
palette: &ColorPalette,
) -> ColorReturn the border color for a panel based on whether it has focus.