fn render_detail_view(
app: &App,
frame: &mut Frame<'_>,
area: Rect,
palette: &ColorPalette,
)Expand description
Render the patchset detail view in the given area.
fn render_detail_view(
app: &App,
frame: &mut Frame<'_>,
area: Rect,
palette: &ColorPalette,
)Render the patchset detail view in the given area.