pub fn execute<S: BuildHasher>(
cmd: Cmd,
clients: &HashMap<String, Arc<dyn SashikoApi>, S>,
active_remote: &str,
msg_tx: &UnboundedSender<Message>,
)Expand description
Execute a command by spawning async tasks that send results
back through msg_tx.
The active_remote key is used to look up the correct client
from clients. If the remote is not found, an error message
is sent instead.